Drip
--------

App registration (get your key and secret here)
    https://www.getdrip.com/user/applications

Authentication documentation
    https://developer.drip.com/?shell#oauth

Development callback URL
    https://localhost:8000/accounts/drip/login/callback/

Make sure the registered application is active.
